"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Orchestrator = void 0;
/**
 * Functions to orchestrate code
 */
class Orchestrator {
    /**
     * Initialize new instance of BaseClass
     * @param logger {ILogger} Logger
     */
    constructor(logger) {
        this.Logger = logger;
    }
    /**
     * Orchestrate a function
     * @param actionToTake {function} Async function to run.
     */
    Orchestrate(actionToTake) {
        const action = `${Orchestrator.name}.${this.OrchestrateAsync.name}`;
        // log that we are starting the orchestrator
        this.Logger.Information(`[${action}] Starting orchestration`);
        let successful = false;
        try {
            // process function
            actionToTake();
            successful = true;
        }
        catch (error) {
            this.Logger.Error(error);
        }
        finally {
            // log that we are finished with the orchestrator
            this.Logger.Information(`[${action}] Finished orchestration`);
        }
        return successful;
    }
    /**
     * Orchestrate a function with async calls in it
     * @param actionToTake {function} Async function to run.
     */
    OrchestrateAsync(actionToTake) {
        return __awaiter(this, void 0, void 0, function* () {
            const action = `${Orchestrator.name}.${this.OrchestrateAsync.name}`;
            // log that we are starting the orchestrator
            this.Logger.Information(`[${action}] Starting orchestration`);
            let successful = false;
            try {
                // process function
                yield actionToTake();
                successful = true;
            }
            catch (error) {
                this.Logger.Error(error);
            }
            finally {
                // log that we are finished with the orchestrator
                this.Logger.Information(`[${action}] Finished orchestration`);
            }
            return successful;
        });
    }
}
exports.Orchestrator = Orchestrator;
//# sourceMappingURL=orchestrator.js.map